@@ -1,5 +1,5 @@
 use super::{now, WAITS, WAITS_NUM};
-use async_ach_waker::{WakerEntity, WakerPool, WakerToken};
+use super::waiter::{Token, Waiter};
 use core::pin::Pin;
 use core::task::{Context, Poll};
 use core::time::Duration;
@@ -15,10 +15,10 @@ pub fn interval(period: Duration) -> Interval {
 }
 
 pub struct Interval {
-    pool: &'static WakerPool<u64, WAITS_NUM>,
+    pool: &'static Waiter< WAITS_NUM>,
     last: u64,
     period: Duration,
-    token: Option<WakerToken<'static, u64, WAITS_NUM>>,
+    token: Option<Token<'static, WAITS_NUM>>,
 }
 impl Stream for Interval {
     type Item = ();
@@ -30,9 +30,9 @@ impl Stream for Interval {
         }
         let waker = cx.waker();
         if let Some(token) = &self.token {
-            token.swap(WakerEntity::new(waker.clone(), next_time));
+            token.swap(waker.clone(), next_time);
         } else if let Ok(token) = self.pool.register() {
-            token.swap(WakerEntity::new(waker.clone(), next_time));
+            token.swap(waker.clone(), next_time);
             self.token = Some(token);
         } else {
             waker.wake_by_ref();
